import type { User } from "@/types/api/user";
import { defineStore } from "pinia";
import { ref } from "vue";

export const useUser = defineStore("user", () => {
  const token = ref<string | null>(uni.getStorageSync('token') || null);
  const userinfo = ref<User | null>(null);

  /**
   * 判断是否有权限
   * @param role 角色类型
   * @returns 是否有权限
   */
  function hasRole(role: "teacher" | "admin" | "liaison" | "sysadmin") {
    if (!userinfo.value) return false;
    
    const roleMap = {
      teacher: 1,   // 教师
      admin: 2,     // 普通管理员
      liaison: 3,   // 沟通联络人
      sysadmin: 4   // 系统管理员
    };
    
    return userinfo.value.roles === roleMap[role];
  }

  /**
   * 判断是否有指定岗位
   * @param job 岗位类型
   * @returns 是否有权限
   */
  function hasJob(job: "teacher" | "projectManager" | "liaison" | "sysManager") {
    if (!userinfo.value) return false;
    
    const jobMap = {
      teacher: 1,        // 课程制作教师
      projectManager: 2, // 课程审核人员
      liaison: 3,        // 校方项目负责人
      sysManager: 4      // 公司系统管理员
    };
    
    return userinfo.value.jobs === jobMap[job];
  }

  /**
   * 判断是否有查看所有课程的权限
   * @returns 是否有权限
   */
  function canViewAllCourses() {
    if (!userinfo.value) return false;
    
    // 系统管理员或普通管理员可以查看所有课程
    if (userinfo.value.roles === 4 || userinfo.value.roles === 2) return true;
    
    // 课程制作方沟通联络人可以查看所有课程
    if (userinfo.value.roles === 3 && userinfo.value.jobs === 3) return true;
    
    return false;
  }

  /**
   * 判断是否有编辑课程的权限
   * @returns 是否有权限
   */
  function canEditCourse() {
    if (!userinfo.value) return false;
    
    // 教师可以编辑自己的课程
    if (userinfo.value.roles === 1) return true;
    
    // 系统管理员可以编辑所有课程
    if (userinfo.value.roles === 4) return true;
    
    return false;
  }

  // 设置 token 并持久化
  function setToken(newToken: string | null) {
    token.value = newToken;
    if (newToken) {
      uni.setStorageSync('token', newToken);
    } else {
      uni.removeStorageSync('token');
    }
  }

  // 检查 token 是否有效
  function hasValidToken(): boolean {
    return !!token.value && token.value.length > 0;
  }

  function logout() {
    token.value = null;
    userinfo.value = null;
  }

  return {
    token,
    userinfo,
    hasRole,
    hasJob,
    canViewAllCourses,
    canEditCourse,
    logout,
    setToken,
    hasValidToken
  };
});
